@@ -7,11 +7,11 @@
 ## http://search.cpan.org/dist/Devel-NYTProf/
 ##
 ###########################################################
-## $Id: NYTProf.pm 998 2009-12-24 14:40:14Z tim.bunce $
+## $Id: NYTProf.pm 1076 2010-02-20 16:31:12Z tim.bunce $
 ###########################################################
 package Devel::NYTProf;
 
-our $VERSION = '3.00';
+our $VERSION = '3.02';
 
 package    # hide the package from the PAUSE indexer
     DB;
@@ -172,7 +172,9 @@ statement executed in foo()>! Here's another example:
 
 After the first time around the loop, any further time spent evaluating the
 condition (waiting for input in this example) would be be recorded as having
-been spent I<on the last statement executed in the loop>!
+been spent I<on the last statement executed in the loop>! (Until perl bug
+#60954 is fixed this problem still applies to some loops. For more information
+see L<http://rt.perl.org/rt3/Ticket/Display.html?id=60954>)
 
 NYTProf avoids these problems by intercepting the opcodes which indicate that
 control is returning into some previous statement and adjusting the profile
@@ -218,7 +220,7 @@ be useful when analyzing the performance. It also records the filename and line
 ranges of all the subroutines.
 
 NYTProf can profile applications that fork, and does so with no loss of
-performance. There's (now) no special 'allowfork' mode. It just works.
+performance.
 NYTProf detects the fork and starts writing a new profile file with the pid
 appended to the filename.
 
@@ -261,7 +263,8 @@ Or you can avoid the need to add the -d option at all by using the C<PERL5OPT> e
   PERL5OPT=-d:NYTProf
 
 That's also very handy when you can't alter the perl command line being used to
-run the script you want to profile.
+run the script you want to profile. Usually you'll want to enable the
+L</addpid=1> option to ensure any nested invocations of perl don't overwrite the profile.
 
 =head1 NYTPROF ENVIRONMENT VARIABLE
 
@@ -418,7 +421,7 @@ The opcodes are currently profiled using their internal names, so C<printf> is C
 and the C<-x> file test is C<fteexec>. This may change in future.
 
 Opcodes that call subroutines, perhaps by triggering a FETCH from a tied
-variable, currently appear in the call tree as the call of the sub. This is
+variable, currently appear in the call tree as the caller of the sub. This is
 likely to change in future.
 
 =head2 usecputime=1
@@ -436,7 +439,8 @@ happen so rarely relative to the activity of a most applications that you'd
 have to run the code for many hours to have any hope of reasonably useful results.
 
 A better alternative would be to use the C<clock=N> option to select a
-high-resolution cpu time clock, if available on your system.
+high-resolution cpu time clock, if available on your system, because that'll
+give you higher resolution and work for the subroutine profiler as well.
 
 =head2 file=...
 
@@ -476,7 +480,7 @@ SEGV, BUS) and ensure a usable by executing:
     exit 1;
 
 You can also specify which signals to catch in this way by listing them,
-seperated by commas, as the value of the option (case is not significant):
+separated by commas, as the value of the option (case is not significant):
 
     sigexit=int,hup
 
@@ -596,6 +600,23 @@ classes is executed on a unicode string you'll find profile data like this:
 =for comment
 No doubt more odd cases will be added here over time.
 
+=head1 MAKING NYTPROF FASTER
+
+You can reduce the cost of profiling by adjusting some options. The trade-off
+is reduced detail and/or accuracy in reports.
+
+If you don't need statement-level profiling then you can disable it via L</stmts=0>.
+If you do need it but don't mind loosing block-level timings then set L</blocks=0>.
+If you want need still more speed then set L</leave=0> to disable the
+adjustments made for statements that 'leave' the current control flow (doing
+this I<will> make timings for some kinds of statements less accurate).
+
+If you don't need subroutine profiling then you can disable it via L</subs=0>.
+If you do need it but don't need timings for perl opcodes then set L</slowops=0>.
+
+Another approach is to only enable NYTProf in the sections of code that
+interest you. See L</RUN-TIME CONTROL OF PROFILING> for more details.
+
 =head1 REPORTS
 
 The L<Devel::NYTProf::Data> module provides a low-level interface for loading
@@ -605,8 +626,6 @@ The L<Devel::NYTProf::Reader> module provides an interface for generating
 arbitrary reports.  This means that you can implement your own output format in
 perl. (Though the module is in a state of flux and may be deprecated soon.)
 
-There is currently no tool to merge multiple data files into one.
-
 Included in the bin directory of this distribution are some scripts which
 turn the raw profile data into more useful formats:
 
@@ -624,6 +643,10 @@ L<http://kcachegrind.sourceforge.net>
 Creates attractive, richly annotated, and fully cross-linked html
 reports (including statistics, source code and color highlighting).
 
+=head2 nytprofmerge
+
+Reads multiple profile data files and writes out a new file containing the merged profile data.
+
 =head1 LIMITATIONS
 
 =head2 Threads and Multiplicity
@@ -838,6 +861,18 @@ Note that processor affinity is inherited by child processes, so if the process
 you're profiling spawns cpu intensive sub processes then your process will be
 impacted by those more than it otherwise would.
 
+=head3 Windows
+
+On Windows NYTProf uses Time::HiRes which uses the windows
+QueryPerformanceCounter() API with some extra logic to adjust for the current
+clock speed and try to resync the raw counter to wallclock time every so often
+(every 30 seconds or if the timer drifts by more than 0.5 of a seconds).
+This extra logic may lead to occasional spurious results.
+
+(It would be great if someone could contribute a patch to NYTProf to use
+QueryPerformanceCounter() directly and avoid the overheads and resyncing
+behaviour of Time::HiRes.)
+
 =head2 Virtual Machines
 
 I recommend you don't do performance profiling while running in a
@@ -885,11 +920,23 @@ it's very likely to be deprecated in a future release).
 L<Devel::NYTProf::ReadStream> is the module that lets you read a profile data
 file as a stream of chunks of data.
 
-=head1 AUTHOR
+=head1 AUTHORS AND CONTRIBUTORS
 
-B<Adam Kaplan>, C<< <akaplan at nytimes.com> >>.
-B<Tim Bunce>, L<http://www.tim.bunce.name> and L<http://blog.timbunce.org>.
-B<Steve Peters>, C<< <steve at fisharerojo.org> >>.
+B<Tim Bunce> (L<http://www.tim.bunce.name> and L<http://blog.timbunce.org>)
+leads the project and has done most of the development work thus far.
+
+B<Nicholas Clark> contributed zip compression and C<nytprofmerge>.
+B<Chia-liang Kao> contributed C<nytprofcg>.
+B<Peter (Stig) Edwards> contributed the VMS port.
+B<Jan Dubois> contributed the Windows port.
+B<Gisle Aas> contributed the Devel::NYTProf::ReadStream module.
+B<Steve Peters> contributed greater perl version portability and use of POSIX
+high-resolution clocks.
+Other contributors are noted in the Changes file.
+
+Many thanks to B<Adam Kaplan> who created C<NYTProf> initially by forking
+C<Devel::FastProf> adding reporting from C<Devel::Cover> and a test suite.
+For more details see L</HISTORY> below.
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -902,7 +949,7 @@ at your option, any later version of Perl 5 you may have available.
 
 =head1 HISTORY
 
-A bit of history and a shameless plug...
+A bit of history (and a shameless plug from Adam)...
 
 NYTProf stands for 'New York Times Profiler'. Indeed, this module was initially
 developed from Devel::FastProf by The New York Times Co. to help our developers
